//
//  NetworkAPI.swift
//  GitHub
//
//  Created by 曹云霄 on 2017/11/30.
//  Copyright © 2017年 曹云霄. All rights reserved.
//

import Foundation
import Moya
import Alamofire
import SwiftyJSON

public enum Service {
    // MARK: - 登录
    case Login(String,String)
    // MARK: - 待办事项查询
    case QueryTodo(QueryTodoModel)
    // MARK: - 新建工单查询来源
    case QuerySource()
    // MARK: - 新建工单服务类型
    case QueryServerType()
    // MARK: - 新建工单优先级
    case QueryPrority()
    // MARK: - 查询报事人
    case QueryInitiator()
    // MARK: - 查询位置
    case QueryPosition()
    // MARK: - 查询设施
    case QueryDevice(DeviceQueryModel)
    // MARK: - 提交工单
    case SubmitOrder(SaveRepairOrderModel)
    // MARK: - 查询工单列表
    case QueryRepairOrder(RepairOrderQueryModel)
    // MARK: - 查询工单详情
    case GetRepairOrderDetail(String)
    // MARK: - 查询子单详情
    case GetChildBillDetail(String)
    // MARK: - 查询工单详情转交部门
    case GetRepairOrderDepartment()
    // MARK: - 工单详情转交
    case TransferOrder(DepartmentQueryModel)
    // MARK: - 工单详情完成
    case CompleteOrder(BillCompletedRequestModel)
    // MARK: - 主管指引/备件/工具
    case QueryToolOption()
    // MARK: - 安全/防护/围封/环保
    case QueryProtectOption()
    // MARK: - 故障原因
    case QuerybrokenOption()
    // MARK: - 处理方式
    case QueryprocessMethods()
    // MARK: - 上传图片附件
    // 图片entityUuid  本地文件路径
    case UploadAttachment(UploadPhotoAttachmentModel)
    // MARK: - 下载图片附件
    // String 附件类型   String 附件id
    case DownloadAttachment(String,String)
    // MARK: - 子工单工单uuid
    case GetChildBill(String)
    // MARK: - 保存及更新子工单
    case SaveChildBill(ChildBillDetailData)
    // MARK: - 完成子工单
    case FinishChildBill(ChildBillDetailData)
    // MARK: - 检查版本更新
    case UpdateVersion()
    // MARK: - 修改密码
    case ChangePassword(String)
}

extension Service: TargetType {
    public var baseURL: URL {
        return URL(string: BaseUrl)!
    }
    
    public var path: String {
        switch self {
        case .Login(let name, _):
            return String(format: loginUrl, name)
        case .QueryTodo(_):
            return todoUrl
        case .QuerySource:
            return sourceUrl
        case .QueryServerType:
            return serviceTypeUrl
        case .QueryPrority:
            return prorityUrl
        case .QueryInitiator():
            return initiatorUrl
        case .QueryPosition():
            return positionUrl
        case .QueryDevice(_):
            return deviceUrl
        case .SubmitOrder(_):
            let path = saveRepairOrderUrl + "?operator.operId=\(kUser().userCode!)&operator.operName=\(kUser().userName!)&time=\(NSDate().httpParameterString()!)"
            return path.urlEncoded()
        case .QueryRepairOrder(_):
            let path = repairOrderUrl + "?operator.operId=\(kUser().userCode!)&operator.operName=\(kUser().userName!)&time=\(NSDate().httpParameterString()!)"
            return path.urlEncoded()
        case .GetRepairOrderDetail(let billNumber):
            return String(format: getBillDetailUrl, billNumber)
        case .GetRepairOrderDepartment:
            return organizationUrl
        case .TransferOrder(_):
            let path = batchTransferUrl + "?operator.operId=\(kUser().userCode!)&operator.operName=\(kUser().userName!)&time=\(NSDate().httpParameterString()!)"
            return path.urlEncoded()
        case .GetChildBill(let billUuid):
            let path = String(format: drawExecute, billUuid) + "?operator.operId=\(kUser().userCode!)&operator.operName=\(kUser().userName!)&time=\(NSDate().httpParameterString()!)"
            return path.urlEncoded()
        case .SaveChildBill(_):
            let path = saveExecute + "?operator.operId=\(kUser().userCode!)&operator.operName=\(kUser().userName!)&time=\(NSDate().httpParameterString()!)"
            return path.urlEncoded()
        case .FinishChildBill(_):
            let path = finishExecute + "?operator.operId=\(kUser().userCode!)&operator.operName=\(kUser().userName!)&time=\(NSDate().httpParameterString()!)"
            return path.urlEncoded()
        case .QueryToolOption:
            return toolOptionUrl
        case .QueryProtectOption:
            return protectOptionUrl
        case .QuerybrokenOption:
            return brokenOptionUrl
        case .QueryprocessMethods:
            return protectOptionUrl
        case .CompleteOrder:
            return completedBillUrl
        case .UploadAttachment(let model):
            return String(format: uploadAttachmentUrl, model.entityType,model.entityUuid)
        case .DownloadAttachment(let entity_type, let entity_uuid):
            return String(format: downloadAttachmentUrl, entity_type,entity_uuid)
        case .GetChildBillDetail(let uuid):
            return String(format: getChildBillDetailUrl, uuid)
        case .UpdateVersion():
            return updateUrl
        case .ChangePassword(_):
            let path = String(format: changePassword, kUser().userUuid,NSDate().httpParameterString(),kUser().userCode,kUser().userName)
            return path.urlEncoded()
        }
    }
    
    public var method: Moya.Method {
        switch self {
        case .Login(_, _),
             .QueryTodo(_),
             .QueryPosition(),
             .QueryDevice(_),
             .SubmitOrder(_),
             .QueryRepairOrder(_),
             .GetRepairOrderDepartment(),
             .TransferOrder(_),
             .CompleteOrder(_),
             .UploadAttachment(_),
             .SaveChildBill(_),
             .ChangePassword(_),
             .FinishChildBill(_),
             .QueryInitiator(_):
            return .post
        case .QuerySource(),
             .QueryServerType(),
             .GetRepairOrderDetail(_),
             .QueryToolOption(),
             .QueryProtectOption(),
             .QuerybrokenOption(),
             .QueryprocessMethods(),
             .DownloadAttachment(_, _),
             .GetChildBill(_),
             .GetChildBillDetail(_),
             .UpdateVersion(),
             .QueryPrority():
            return .get
        }
    }
    
    public var sampleData: Data {
        return "Create post successfully".data(using: String.Encoding.utf8)!
    }
    
    public var task: Task {
        switch self {
        case .Login(_, let password):
            return .requestParameters(parameters: ["password": password,
                                                   "authenticode": "211534962"],
                                      encoding: JSONEncoding.default)
        case .ChangePassword(let password):
            let oldPassword = NSString(string: kUser().password)
            let newPassword = NSString(string: password)
            return .requestParameters(parameters: ["newPassword": newPassword.md5(),
                                                   "oldPassword": oldPassword.md5()],
                                      encoding: JSONEncoding.default)
        case .QueryTodo(let model):
            return .requestParameters(parameters: model.toDictionary(),
                                      encoding: JSONEncoding.default)
        case .QuerySource(),
             .QueryServerType(),
             .GetRepairOrderDetail(_),
             .QueryToolOption(),
             .QueryProtectOption(),
             .QuerybrokenOption(),
             .QueryprocessMethods(),
             .GetChildBillDetail(_),
             .DownloadAttachment(_,_),
             .UpdateVersion(),
             .GetChildBill(_),
             .QueryPrority():
            return .requestPlain
        case .QueryInitiator(),
             .GetRepairOrderDepartment(),
             .QueryPosition():
            let model = EmptyModel()
            return .requestParameters(parameters: model.toJSON()!,
                                      encoding: JSONEncoding.default)
        case .QueryDevice(let queryModel):
            return .requestParameters(parameters: queryModel.toDictionary(),
                                     encoding: JSONEncoding.default)
        case .SubmitOrder(let submitModel):
            return .requestParameters(parameters: submitModel.toDictionary(),
                                      encoding: JSONEncoding.default)
        case .QueryRepairOrder(let queryModel):
            return .requestParameters(parameters: queryModel.toDictionary(),
                                      encoding: JSONEncoding.default)
        case .TransferOrder(let queryModel):
            return .requestParameters(parameters: queryModel.toDictionary(),
                                      encoding: JSONEncoding.default)
        case .CompleteOrder(let queryModel):
            return .requestParameters(parameters: queryModel.toDictionary(),
                                      encoding: JSONEncoding.default)
        case .UploadAttachment(let attachmentModel):
            let data = MultipartFormData(provider: .file(URL(fileURLWithPath: attachmentModel.fileUrl)), name: "file", fileName: attachmentModel.fileName, mimeType: "image/jpeg")
            return .uploadMultipart([data])
        case .SaveChildBill(let model):
            return .requestParameters(parameters: model.toDictionary(), encoding: JSONEncoding.default)
        case .FinishChildBill(let model):
            return .requestParameters(parameters: model.toDictionary(), encoding: JSONEncoding.default)
        }
    }
    
    public var headers: [String : String]? {
        return ["device" : UIDevice.current.name]
    }
}












