//
//  FilterViewModel.swift
//  IFS
//
//  Created by 曹云霄 on 2018/1/4.
//  Copyright © 2018年 上海勾芒信息科技有限公司. All rights reserved.
//

import UIKit
import RxSwift

class FilterViewModel: BaseViewModel {

    /// 公共过滤数组,需要把外界传入数据转化为此类型
    lazy final var filterArray: NSMutableArray = {
        var filterArray = NSMutableArray()
        return filterArray
    }()
    
    /// 过滤后显示数据源
    lazy final var displayArray: NSArray = {
        var displayArray = NSArray()
        return displayArray
    }()
}

// MARK: - UI
extension FilterViewModel {
    
    func dequeueReusableCell(_ indexPath: IndexPath,_ identifier: String, _ tableView: UITableView) ->UITableViewCell {
        let publicFilterCell = tableView.dequeueReusableCell(withIdentifier: identifier, for: indexPath) as! FilterTableViewCell
        let model = displayArray[indexPath.row] as! PublicFilterModel
        publicFilterCell.accessoryType = model.isSelected == "\(kONE)" ? .checkmark : .none
        publicFilterCell.titleLabel.text = model.title
        return publicFilterCell
    }
    
    // MARK: - 选择item
    func deselectRow(_ indexPath: IndexPath, _ type: FILTER_TYPE){
        if (displayArray[indexPath.row] as! PublicFilterModel).isSelected == "\(kONE)" {
            (displayArray[indexPath.row] as! PublicFilterModel).isSelected = "\(kZERO)"
        }else {
            if type == .SINGLE {
                for model in displayArray {
                    (model as! PublicFilterModel).isSelected = "\(kZERO)"
                }
                for model in filterArray {
                    (model as! PublicFilterModel).isSelected = "\(kZERO)"
                }
            }
            (displayArray[indexPath.row] as! PublicFilterModel).isSelected = "\(kONE)"
        }
    }
}

// MARK: - 数据请求
extension FilterViewModel {
    // MARK: - 查询工程发起方
    func queryProjectSponsors() ->Observable<[String]> {
        return Observable.create({ (observer) -> Disposable in
            Network.request(target: .QuerySource(), success: { (json) in
                let resultModel = ProjectSponsorsModel(fromJson: json)
                if resultModel.success {
                    observer.onNext(resultModel.data)
                }else {
                    ShowMessage(resultModel.message)
                }
            }, failure: { (error) in
                ShowMessage(error.localizedDescription)
            })
            return Disposables.create()
        })
    }
    
    // MARK: - 查询服务类型
    func queryServerType() ->Observable<[String]> {
        return Observable.create({ (observer) -> Disposable in
            Network.request(target: .QueryServerType(), success: { (json) in
                let resultModel = ProjectSponsorsModel(fromJson: json)
                if resultModel.success {
                    observer.onNext(resultModel.data)
                }else {
                    ShowMessage(resultModel.message)
                }
            }, failure: { (error) in
                ShowMessage(error.localizedDescription)
            })
            return Disposables.create()
        })
    }
    
    // MARK: - 查询优先级
    func queryProrityOption() ->Observable<[String]> {
        return Observable.create({ (observer) -> Disposable in
            Network.request(target: .QueryPrority(), success: { (json) in
                let resultModel = ProjectSponsorsModel(fromJson: json)
                if resultModel.success {
                    observer.onNext(resultModel.data)
                }else {
                    ShowMessage(resultModel.message)
                }
            }, failure: { (error) in
                ShowMessage(error.localizedDescription)
            })
            return Disposables.create()
        })
    }
    
    // MARK: - 查询报事人
    func queryInitiator() ->Observable<[InitiatorRecord]> {
        return Observable.create({ (observer) -> Disposable in
            Network.request(target: .QueryInitiator(), success: { (json) in
                let resultModel = InitiatorModel(fromJson: json)
                if resultModel.success {
                    observer.onNext(resultModel.data.records)
                }else {
                    ShowMessage(resultModel.message)
                }
            }, failure: { (error) in
                ShowMessage(error.localizedDescription)
            })
            return Disposables.create()
        })
    }
    
    // MARK: - 查询报事人位置
    func queryLocation() ->Observable<[LocationRecord]> {
        return Observable.create({ (observer) -> Disposable in
            Network.request(target: .QueryPosition(), success: { (json) in
                let resultModel = LocationModel(fromJson: json)
                if resultModel.success {
                    observer.onNext(resultModel.data.records)
                }else {
                    ShowMessage(resultModel.message)
                }
            }, failure: { (error) in
                ShowMessage(error.localizedDescription)
            })
            return Disposables.create()
        })
    }
    
    // MARK: - 查询设施
    func queryDevice() ->Observable<[DeviceRecord]> {
        let queryModel = DeviceQueryModel()
        return Observable.create({ (observer) -> Disposable in
            Network.request(target: .QueryDevice(queryModel), success: { (json) in
                let resultModel = DeviceModel(fromJson: json)
                if resultModel.success {
                    observer.onNext(resultModel.data.records)
                }else {
                    ShowMessage(resultModel.message)
                }
            }, failure: { (error) in
                ShowMessage(error.localizedDescription)
            })
            return Disposables.create()
        })
    }
    
    // MARK: - 主管指引/备件/工具
    func queryToolOption() ->Observable<[String]> {
        return Observable.create({ (observer) -> Disposable in
            Network.request(target: .QueryToolOption(), success: { (json) in
                let resultModel = ProjectSponsorsModel(fromJson: json)
                if resultModel.success {
                    observer.onNext(resultModel.data)
                }else {
                    ShowMessage(resultModel.message)
                }
            }, failure: { (error) in
                ShowMessage(error.localizedDescription)
            })
            return Disposables.create()
        })
    }
    
    // MARK: - 安全/防护/围封/环保
    func queryProtectOption() ->Observable<[String]> {
        return Observable.create({ (observer) -> Disposable in
            Network.request(target: .QueryProtectOption(), success: { (json) in
                let resultModel = ProjectSponsorsModel(fromJson: json)
                if resultModel.success {
                    observer.onNext(resultModel.data)
                }else {
                    ShowMessage(resultModel.message)
                }
            }, failure: { (error) in
                ShowMessage(error.localizedDescription)
            })
            return Disposables.create()
        })
    }
    
    // MARK: - 故障原因
    func queryBrokenOption() ->Observable<[String]> {
        return Observable.create({ (observer) -> Disposable in
            Network.request(target: .QuerybrokenOption(), success: { (json) in
                let resultModel = ProjectSponsorsModel(fromJson: json)
                if resultModel.success {
                    observer.onNext(resultModel.data)
                }else {
                    ShowMessage(resultModel.message)
                }
            }, failure: { (error) in
                ShowMessage(error.localizedDescription)
            })
            return Disposables.create()
        })
    }
    
    // MARK: - 处理方式
    func queryProcessMethods() ->Observable<[String]> {
        return Observable.create({ (observer) -> Disposable in
            Network.request(target: .QueryprocessMethods(), success: { (json) in
                let resultModel = ProjectSponsorsModel(fromJson: json)
                if resultModel.success {
                    observer.onNext(resultModel.data)
                }else {
                    ShowMessage(resultModel.message)
                }
            }, failure: { (error) in
                ShowMessage(error.localizedDescription)
            })
            return Disposables.create()
        })
    }
}









