//
//  RepairOrderDetailBgController.swift
//  IFS
//
//  Created by 曹云霄 on 2018/1/12.
//  Copyright © 2018年 上海勾芒信息科技有限公司. All rights reserved.
//

import UIKit
import SnapKit
import SwiftyJSON
import RxSwift

class RepairOrderDetailBgController: BaseViewController {

    /// 工单数据
    open var billModel: RepairOrderRecord!
    /// 转交、完成背景
    @IBOutlet weak var bottomBgView: UIView!
    @IBOutlet weak var bottomLayoutHeight: NSLayoutConstraint!
    /// 详情内容背景
    @IBOutlet weak var contentBgView: UIView!
    /// 转交
    @IBOutlet weak var transferButton: UIButton!
    /// 完成
    @IBOutlet weak var completeButton: UIButton!
    /// 工单详情控制器
    lazy final var detailVc: RepairOrderDetailViewController = {
        var detailVc = RepairOrderDetailViewController.instantiateViewController(.Function) as! RepairOrderDetailViewController
        return detailVc
    }()
    /// RxSwift自动释放
    let disposeBag = DisposeBag()
    /// 悬浮View
    var suspendView: RepairOrderDetailSuspendView?
    /// 工单详情ViewModel
    lazy final var orderDetailViewModel: RepairOrderDetailViewModel = {
        var orderDetailViewModel = RepairOrderDetailViewModel()
        return orderDetailViewModel
    }()
    
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        uiConfigAction()
        addChildBillDetailVc()
    }
    
    // MARK: - UI
    fileprivate func uiConfigAction() {
        bottomBgView.addShadow(UIColor.black)
    }

    // MARK: - 添加工单详情控制器
    fileprivate func addChildBillDetailVc() {
        detailVc.billModel = billModel
        contentBgView.addSubview(detailVc.view)
        detailVc.view.snp.makeConstraints { (make) in
            make.edges.equalTo(self.contentBgView)
        }
        addChildViewController(detailVc)
        detailVc.setStateBlock {[weak self] (state) in
            self?.rapairBillBottomViewAction(state)
        }
        detailVc.setSuspendViewAlphaBlock {[weak self] (alpha) in
            self?.suspendView?.alpha = alpha
        }
        detailVc.setSuspendViewStateBlock {[weak self] (model, indexPath,state) in
            if state == SUBMIT_REPAIR_ORDER_STATE.INIT.rawValue {
                self?.setupSuspendViewAction(model,indexPath)
            }else {
                UIView.animate(withDuration: kAnimationTime, animations: {
                    self?.suspendView?.seth(h: kHeight)
                }, completion: { (bool) in
                    self?.suspendView?.removeFromSuperview()
                })
            }
        }
    }
    
    // MARK: - 转交工单
    @IBAction func transferButtonClickAction(_ sender: UIButton) {
        detailVc.transferRepairOrder()
    }
    
    // MARK: - 传递工单数据到工单完成界面
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        if segue.identifier == RepairOrderCompletedViewController.name() {
            let completeVc = segue.destination as! RepairOrderCompletedViewController
            let model = BillCompletedRequestModel(fromJson: JSON(detailVc.orderDetailViewModel.billDetailModel.toDictionary()))
            completeVc.setStateBlock({[weak self] (state) in
                self?.rapairBillBottomViewAction(state)
            })
            completeVc.billCompleteViewModel.billCompltedModel = model
        }
    }
    
    // MARK: - 工单底部view
    fileprivate func rapairBillBottomViewAction(_ state: String) {
        if state == SUBMIT_REPAIR_ORDER_STATE.FINISHED.rawValue || state == SUBMIT_REPAIR_ORDER_STATE.DELETED.rawValue || state == SUBMIT_REPAIR_ORDER_STATE.CANCLED.rawValue {
            bottomLayoutHeight.constant = 0
            UIView.animate(withDuration: kAnimationTime, animations: {
                self.view.layoutIfNeeded()
            })
        }else {
            bottomLayoutHeight.constant = 50
            UIView.animate(withDuration: kAnimationTime, animations: {
                self.view.layoutIfNeeded()
            })
        }
    }
    
    // MARK: - 设置悬浮框
    fileprivate func setupSuspendViewAction(_ model: BillDetailExecute, _ indexPath: IndexPath) {
        let suspendView = RepairOrderDetailSuspendView.instantiateFromNib() as! RepairOrderDetailSuspendView
        suspendView.updateSuspendView(model, indexPath)
        suspendView.frame = CGRect(x: 15, y: kHeight, width: kWidth - 30, height: 60)
        self.suspendView = suspendView
        self.view.addSubview(suspendView)
        self.view.bringSubview(toFront: suspendView)
        UIView.animate(withDuration: kAnimationTime, animations: {
            suspendView.sety(y: self.view.height - kNavHeight - kTabBarHeight)
        })
        suspendView.operationOrderBtn.rx.controlEvent(UIControlEvents.touchUpInside).subscribe(onNext: {[weak self] (event) in
            self?.detailVc.suspendViewButtonClickAction(suspendView.operationOrderBtn.currentTitle!,model,indexPath)
        }).disposed(by: disposeBag)
    }
}



